<?php
class GD {
    var $Image;
    var $Width;
    var $Height;

    function GD ($location) {
        $ImageInfo    = @getimagesize( $location ) or die( "NAPAKA [01]: Fotografija <b>$location</b> ne obstaja!" );
        $this->Width    = $ImageInfo[0];
        $this->Height    = $ImageInfo[1];
        
        switch ( $ImageInfo[2] ) {
            case 1:    $this->Image = imagecreatefromgif( $location );        break;
            case 2:    $this->Image = imagecreatefromjpeg( $location );    break;
            case 3:    $this->Image = imagecreatefrompng( $location );        break;
            default:    die( "NAPAKA [02]: Skripta ne podpira tega tipa fotografij!" );
        }
    }

    function Resize ($sizeX, $sizeY) {
        $org        = round( $this->Width / $this->Height, 2 );
        $new        = round( $sizeX / $sizeY, 2 );

        if ( $new > $org ) {
            $sizeX    = round( $this->Width / ($this->Height / $sizeY), 0 );
            $sizeY    = $sizeY;
        } else
        if ( $new < $org ) {
            $sizeX    = $sizeX;
            $sizeY    = round( $this->Height / ($this->Width / $sizeX), 0 );
        }

        $resized        = imagecreatetruecolor( $sizeX, $sizeY );
        imagecopyresampled( $resized, $this->Image, 0, 0, 0, 0, $sizeX, $sizeY, $this->Width, $this->Height );

        $this->Image    = $resized;

        $this->Width    = $sizeX;
        $this->Height    = $sizeY;
    }

    function Make_Color ($color) {
        $rgb        = array();

        if ( is_array( $color ) && count($color) == 3 ) {
            $rgb["r"]        = $color[0];
            $rgb["g"]        = $color[1];
            $rgb["b"]        = $color[2];
        }
        else
        if ( preg_match('/^#?([a-f0-9]{2})([a-f0-9]{2})([a-f0-9]{2})$/i', $color, $results) ) {
            $rgb["r"]        = hexdec( $results[1] );
            $rgb["g"]        = hexdec( $results[2] );
            $rgb["b"]        = hexdec( $results[3] );
        } 
        else
            die( "NAPAKA [03]: Podana barva je napacna!" );

        foreach ( array("r","g","b") as $value ) {
            if ( !array_key_exists( $value, $rgb ) || $rgb[$value] < 0 || $rgb[$value] > 255 || !is_numeric( $rgb[$value] ) )
                die ( "NAPAKA [04]: Barva <b>$rgb[$value]</b> je napacna!" );
        }

        return $rgb;
    }


    function Add_Border ($width, $color) {
        $rgb        = $this->Make_Color( $color );
        $allocate        = imagecolorallocate( $this->Image, $rgb["r"], $rgb["g"], $rgb["b"] );

        if ( $width < 1 )
            die ( "NAPAKA [05]: Podaj pravilno irino okvirja!" );


        $sizeX        = $this->Width + ( 2 * $width );
        $sizeY        = $this->Height + ( 2 * $width );
        $new_image    = imagecreatetruecolor( $sizeX, $sizeY );
        imagefill( $new_image, 0, 0, $allocate );
        imagecopyresampled($new_image, $this->Image, $width, $width, 0, 0, $this->Width, $this->Height, $this->Width, $this->Height);

        $this->Image    = $new_image;
        $this->Width    = $sizeX;
        $this->Height    = $sizeY;
    }

    function Add_Text ($text, $font, $color, $x, $y) {
        if ($font < 1 || $font > 5)
            die ( "NAPAKA [06]: Font <b>$font_size</b> neobstaja. Izberi monost med 1 in 5!" );

        $rgb        = $this->Make_Color( $color );
        $allocate        = imagecolorallocate( $this->Image, $rgb["r"], $rgb["g"], $rgb["b"] );
        $text_width    = imagefontwidth( $font ) * strlen( $text );
        $text_height    = imagefontheight( $font );

        if ( $x==TOP && $y==LEFT ) {
            $x    = 0;
            $y    = 0;
        } else
        if ( $x==TOP && $y==RIGHT ) {
            $x    = intval($this->Width - $text_width);
            $y    = 0;
        } else
        if ( $x==TOP && $y==CENTER ) {
            $x    = intval( ($this->Width - $text_width) / 2 );
            $y    = 0;
        } else
        if ( $x==BOTTOM && $y==LEFT ) {
            $x    = 0;
            $y    = intval( $this->Height - $text_height );
        } else
        if ( $x==BOTTOM && $y==RIGHT ) {
            $x    = intval( $this->Width - $text_width );
            $y    = intval( $this->Height - $text_height );
        } else
        if ( $x==BOTTOM && $y==CENTER ) {
            $x    = intval( ($this->Width - $text_width) / 2 );
            $y    = intval( $this->Height - $text_height );
        }

        if ( is_int($x) && is_int($y) ) {
            if ( ($x + $text_width) > $this->Width )
                die ( "NAPAKA [08.w]: Tekst je predolg!" );
            if ( ($y + $text_height) > $this->Height )
                die ( "NAPAKA [08.h]: Tekst je prenizko!" );
            
            imagestring( $this->Image, $font, $x, $y, $text, $allocate);
        } else
            die( "NAPAKA [07]: Vpii pravilno pozicijo teksta!" );
    }

    function Add_TTF_Text ($text, $size, $color, $x, $y, $font = "./tahoma.ttf") {
        if ( !is_file( $font ) )
            die ( "NAPAKA [09]: Font <b>$font</b> ne obstaja!" );

        $rgb        = $this->Make_Color( $color );
        $allocate        = imagecolorallocate( $this->Image, $rgb["r"], $rgb["g"], $rgb["b"] );
        imagettftext($this->Image, $size, 0, $x, $y, $allocate, $font, $text );
    }

    function Save ($location, $quality=80) {
        imagejpeg( $this->Image, $location, $quality );
        imagedestroy( $this->Image );
    }
}
?>